
/* 1. Theme default css */
@import 'varriable';
body {
	
	font-family: $font2;
	font-weight: normal;
	font-style: normal;
	overflow-x: hidden;
    
}


@import 'mixins.scss';
.img {
	max-width: 100%;
	@include transition(.3s);
}
a,
.button {
@include transition(.3s);
}
a:focus,
.button:focus,button:focus {
	text-decoration: none;
	outline: none;
}
a:focus{
	color: #fff;
	text-decoration: none;
}
a:focus,
a:hover,
.portfolio-cat a:hover,
.footer -menu li a:hover {
	text-decoration: none;
	// color: #000;
}
a,
button {
	color: #1F1F1F;
	outline: medium none;
}
h1,h2,h3,h4,h5{
	font-family: $font2;
	color: #1F1F1F;
}
h1 a,
h2 a,
h3 a,
h4 a,
h5 a,
h6 a {
	color: inherit;
}

ul {
	margin: 0px;
	padding: 0px;
}
li {
	list-style: none
}
p {
	font-size: 16px;
	font-weight:400;
	line-height: 28px;
	color: #727272;
	margin-bottom: 13px;
	font-family: $font2;
}

label {
	color: #7e7e7e;
	cursor: pointer;
	font-size: 14px;
	font-weight: 400;
}
*::-moz-selection {
	background: #444;
	color: #fff;
	text-shadow: none;
}
::-moz-selection {
	background: #444;
	color: #fff;
	text-shadow: none;
}
::selection {
	background: #444;
	color: #fff;
	text-shadow: none;
}
*::-webkit-input-placeholder {
	color: #cccccc;
	font-size: 14px;
	opacity: 1;
}
*:-ms-input-placeholder {
	color: #cccccc;
	font-size: 14px;
	opacity: 1;
}
*::-ms-input-placeholder {
	color: #cccccc;
	font-size: 14px;
	opacity: 1;
}
*::placeholder {
	color: #cccccc;
	font-size: 14px;
	opacity: 1;
}

h3{
	font-size: 24px;
}

.mb-65{
	margin-bottom: 67px;
}
// default-bg-color
.black-bg{
	background: #020c26 !important;
}

.white-bg{
	background: #ffffff;
}
.gray-bg{
	background: #FFF5F5;
}



// background-image
.bg-img-1{
    background-image: url(../img/slider/slider-img-1.jpg);
}
.bg-img-2{
    background-image: url(../img/background-img/bg-img-2.jpg);
}
.cta-bg-1{
    background-image: url(../img/background-img/bg-img-3.jpg);

}

.overlay{
	position: relative;
	z-index: 0;
}
.overlay::before{
	position: absolute;
	content: "";
	background-color: rgb(2, 12, 38);
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: -1;
	opacity: 0.851;
}

.overlay2{
	position: relative;
	z-index: 0;
}
.overlay2::before{
	position: absolute;
	content: "";
	background-color: #fff;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: -1;
	opacity: 0.2;
}


.overlay3{
	position: relative;
	z-index: 0;
}
.overlay3::before{
	position: absolute;
	content: "";
	background-color: #fff;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: -1;
	opacity: 0.1;
}
.section-padding{
	padding-top: 120px;
	padding-bottom: 120px;
}
.pt-120{
	padding-top: 120px;
}

/* button style */
.owl-carousel {
	.owl-nav div {
		background: transparent;
		height: 40px;
		left: 0px;
		line-height: 40px;
		// opacity: 0;
		position: absolute;
		text-align: center;
		top: 50%;
		-webkit-transform: translateY(-50%);
			-ms-transform: translateY(-50%);
				transform: translateY(-50%);
		-webkit-transition: all 0.3s ease 0s;
		-o-transition: all 0.3s ease 0s;
		transition: all 0.3s ease 0s;
		// visibility: hidden;
		font-size: 25px;
		color: #fff;
		background: transparent ;
		border-radius: 10px;
		width: 40px;
		border: 1px solid #5D5C5C;
	}
	.owl-nav{
		div{
			&.owl-next{
				// left: 86px;
				// right: auto;
				left: auto;
				right: 0;
				i{
					position: relative;
					right: -1px;
					top: -2px;
				}
			}
			&.owl-prev{
				i{
					position: relative;
					right: 1px;
					top: -2px;
				}
			}
		}
	}
	&:hover{
		.owl-nav{
			div{
				opacity: 1;
				visibility: visible;
				&:hover{
					color: #000;
					background: #fff;
					border: 1px solid #fff;
				}
			}
		}
	}
}

  